import { EventEmitter } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { AuthenticationServiceConfig } from './../model/authentication.service.config';
import { SharePointService } from './../../sharepoint/services/sharepoint.service';
/**
 * Authenticate Active Directory user
 */
export declare class AuthenticationService {
    private http;
    private sharePointService;
    /**
     * @ignore
     */
    private authenticationApiUrl;
    authenticatedChanged: EventEmitter<boolean>;
    authenticatingChanged: EventEmitter<boolean>;
    /**
     * Flag set to true while the service is attempting to authenticate the user
     */
    authenticating: boolean;
    /**
     * Flag set to true when the user is successfully authenticated
     */
    authenticated: boolean;
    /**
     * Object representing the authenticated user
     */
    authenticatedUser: {
        admin: boolean;
        accountName: string;
        displayName: string;
        distinguishedName: string;
        employeeNumber: string;
        photoUrl?: string;
        memberOf?: string;
    };
    /**
     * @ignore
     */
    constructor(config: AuthenticationServiceConfig, http: HttpClient, sharePointService: SharePointService);
    /**
     * Authenticate the user and store the token in Local Storage
     *
     * @param username AD sAMAccountName
     * @param password
     * @param adminGroup AD group that determines if authenticated user is considered an administrator of the app
     */
    login(username: string, password: string, adminGroup?: string): void;
    /**
     * Logout the user and delete the token from Local Storage
     */
    logout(): void;
    /**
     * @ignore
     */
    private validateUser;
    /**
     * @ignore
     */
    private getPhoto;
    /**
     * @ignore
     */
    private checkForExistingToken;
}
